summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/buttongroup.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/buttongroup.h')
-rw-r--r--kalarm/lib/buttongroup.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kalarm/lib/buttongroup.h b/kalarm/lib/buttongroup.h
index 9d4a8886..f4d81265 100644
--- a/kalarm/lib/buttongroup.h
+++ b/kalarm/lib/buttongroup.h
@@ -41,31 +41,31 @@ class ButtonGroup : public TQButtonGroup
TQ_OBJECT
public:
/** Constructor.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit ButtonGroup(TQWidget* tqparent, const char* name = 0);
+ explicit ButtonGroup(TQWidget* parent, const char* name = 0);
/** Constructor.
* @param title The title displayed for this button group.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- ButtonGroup(const TQString& title, TQWidget* tqparent, const char* name = 0);
+ ButtonGroup(const TQString& title, TQWidget* parent, const char* name = 0);
/** Constructor.
* @param strips The number of rows or columns of buttons.
* @param orient The orientation (TQt::Horizontal or TQt::Vertical) of the button group.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- ButtonGroup(int strips, Qt::Orientation orient, TQWidget* tqparent, const char* name = 0);
+ ButtonGroup(int strips, Qt::Orientation orient, TQWidget* parent, const char* name = 0);
/** Constructor.
* @param strips The number of rows or columns of buttons.
* @param orient The orientation (TQt::Horizontal or TQt::Vertical) of the button group.
* @param title The title displayed for this button group.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- ButtonGroup(int strips, Qt::Orientation orient, const TQString& title, TQWidget* tqparent, const char* name = 0);
+ ButtonGroup(int strips, Qt::Orientation orient, const TQString& title, TQWidget* parent, const char* name = 0);
/** Inserts a button in the group.
* This overrides the insert() method of TQButtonGroup, which should really be a virtual method...
* @param button The button to insert.
@@ -41,31 +41,31 @@ class ButtonGroup : public TQButtonGroup
public:
/** Constructor.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -41,31 +41,31 @@ class ButtonGroup : public TQButtonGroup
/** Constructor.
* @param title The title displayed for this button group.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -41,31 +41,31 @@ class ButtonGroup : public TQButtonGroup
* @param strips The number of rows or columns of buttons.
* @param orient The orientation (TQt::Horizontal or TQt::Vertical) of the button group.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -41,31 +41,31 @@ class ButtonGroup : public TQButtonGroup
* @param orient The orientation (TQt::Horizontal or TQt::Vertical) of the button group.
* @param title The title displayed for this button group.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/